<?php

/*
Plugin Name: Advanced Custom Fields: Range Slider
Plugin URI: PLUGIN_URL
Description: Ion Rangeslider coupled to ACF custom field type template
Version: 1.0.0
Author:Oscar from Sesame Street.
Author URI: https://github.com/AdvancedCustomFields/acf-field-type-template 
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

// exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;



// check if class already exists
if( !class_exists('io_acf_plugin_range_slider') ) :
    



class io_acf_plugin_range_slider {
	
	// vars
	var $settings;
	
	
	/*
	*  __construct
	*
	*  This function will setup the class functionality
	*
	*  @type	function
	*  @date	17/02/2016
	*  @since	1.0.0
	*
	*  @param	void
	*  @return	void
	*/
	
	function __construct() {
	        
	
		// settings
		// - these will be passed into the field class.
		$this->settings = array(
			'version'	=> '1.0.0',
			'url'		=> plugin_dir_url( __FILE__ ),
			'path'		=> plugin_dir_path( __FILE__ )
		);
		
		
		// include field
		add_action('acf/include_field_types', 	array($this, 'include_field')); // v5
		add_action('acf/register_fields', 		array($this, 'include_field')); // v4
	}
	
	
	/*
	*  include_field
	*
	*  This function will include the field type class
	*
	*  @type	function
	*  @date	17/02/2016
	*  @since	1.0.0
	*
	*  @param	$version (int) major ACF version. Defaults to false
	*  @return	void
	*/
	
	function include_field( $version = false ) {
		
		// support empty $version
		if( !$version ) $version = 4;
		
		
		// load textdomain
		load_plugin_textdomain( 'acf-range-slider', false, plugin_basename( dirname( __FILE__ ) ) . '/lang' ); 
		
		
		// include
		include_once('fields/class-io-acf-field-range-slider-v' . $version . '.php');
	}
	
}

// initialize

		// register & include JS
		 wp_register_script('acf-range-slider', plugins_url("acf-range-slider/assets/js/input.js"), array('acf-input'));
		 wp_enqueue_script('acf-range-slider');
		
		wp_register_script('ion-range-slider', "https://cdnjs.cloudflare.com/ajax/libs/ion-rangeslider/2.3.1/js/ion.rangeSlider.min.js");
		wp_enqueue_script('ion-range-slider');
		
		
		// register & include CSS
		 wp_register_style('acf-range-slider', plugins_url("acf-range-slider/assets/css/input.css"), array('acf-input'));
		 wp_enqueue_style('acf-range-slider');
		 
		wp_register_style('ion-range-slider', "https://cdnjs.cloudflare.com/ajax/libs/ion-rangeslider/2.3.1/css/ion.rangeSlider.min.css");
		wp_enqueue_style('ion-range-slider');



new io_acf_plugin_range_slider();


// class_exists check
endif;
	
?>